<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:strip-space elements="*"/>
	<xsl:output method="html" indent="yes" encoding="utf-8"/>
	
	<xsl:template match="USERS">
		<input type="hidden" name="tab" value="users"/>
		<input type="hidden" name="pageNum" value=""/>
		<input type="hidden" name="pageSize" value=""/>
		<input type="hidden" name="orderBy" value=""/>
		<input type="hidden" name="orderType" value=""/>
		
		<xsl:apply-templates select="TOOLBAR"/>
		<xsl:apply-templates select="PAGED-LIST"/>
		
		<script language="javascript">	
			function unlockUsers() {
				if (countSelectedCheckBoxes() > 0) {
					self.sbApplyChangesObject.registerForcedSaving(); 
					setWizardFormAction('<xsl:value-of select="/SITEBUILDER-PAGE/VIEW-CONTENT/@ACTION"/>/Modules/Login/Activate');
					sbNavigationObject.go();
				} else {
					alert(SbGetLocaleByKey('SELECT-FOR-DELETE'));
				}
			}
			
			function lockUsers() {
				if (countSelectedCheckBoxes() > 0) {
					self.sbApplyChangesObject.registerForcedSaving(); 
					setWizardFormAction('<xsl:value-of select="/SITEBUILDER-PAGE/VIEW-CONTENT/@ACTION"/>/Modules/Login/Deactivate');
					sbNavigationObject.go();
				} else {
					alert(SbGetLocaleByKey('SELECT-FOR-DELETE'));
				}
			}
			
			function deleteUsers() {
				if (countSelectedCheckBoxes() > 0) {
					if (confirm(SbGetLocaleByKey('SURE-TO-DELETE'))) {
						self.sbApplyChangesObject.registerForcedSaving(); 
						setWizardFormAction('<xsl:value-of select="/SITEBUILDER-PAGE/VIEW-CONTENT/@ACTION"/>/Modules/Login/Delete');
						sbNavigationObject.go();
					}
				} else {
					alert(SbGetLocaleByKey('SELECT-FOR-DELETE'));
				}
			}
			
			function countSelectedCheckBoxes() {
				result = 0;
				var form = document.forms['SB_WizardForm'];
				for (var n = 0; n &lt; form.elements.length; n++) {
					if (form.elements[n].type == 'checkbox' &amp;&amp; form.elements[n].name=='objectIds[]') {
						if (form.elements[n].checked) {
							++result;
						}
					}
				}
				return result;
			}
			
			function setCheckboxStatus(status) {
				var form = document.forms['SB_WizardForm'];
				for (var n = 0; n &lt; form.elements.length; n++) {
					if (form.elements[n].type == 'checkbox' &amp;&amp; form.elements[n].name=='objectIds[]') {
						if (!form.elements[n].disabled) {
							form.elements[n].checked = status;
						}
					}
				}
			}
		</script>
	</xsl:template>
	
	<xsl:template match="USERS/PAGED-LIST/LIST/HEADER">
		<tr class="fixed">
			<th style="width:1%;">
				<div><input type="checkbox" name="globalCheck" onclick="setCheckboxStatus(this.checked);" class="check"/></div>
			</th>
					
			<xsl:call-template name="LIST-HEADER-ITEM">
				<xsl:with-param name="field">status</xsl:with-param>
				<xsl:with-param name="title"><xsl:value-of select="STATUS"/></xsl:with-param>
				<xsl:with-param name="width">1%</xsl:with-param>
				<xsl:with-param name="currentSortField"><xsl:value-of select="../../LIST/@ORDER-BY"/></xsl:with-param>
				<xsl:with-param name="currentSortType"><xsl:value-of select="../../LIST/@ORDER-TYPE"/></xsl:with-param>
				<xsl:with-param name="align">center</xsl:with-param>
				<xsl:with-param name="tab">users</xsl:with-param>
			</xsl:call-template>
			
			<xsl:call-template name="LIST-HEADER-ITEM">
				<xsl:with-param name="field">name</xsl:with-param>
				<xsl:with-param name="title"><xsl:value-of select="USER-NAME"/></xsl:with-param>
				<xsl:with-param name="currentSortField"><xsl:value-of select="../../LIST/@ORDER-BY"/></xsl:with-param>
				<xsl:with-param name="currentSortType"><xsl:value-of select="../../LIST/@ORDER-TYPE"/></xsl:with-param>
				<xsl:with-param name="tab">users</xsl:with-param>
			</xsl:call-template>
		
			<xsl:call-template name="LIST-HEADER-ITEM">
				<xsl:with-param name="field">email</xsl:with-param>
				<xsl:with-param name="title"><xsl:value-of select="EMAIL"/></xsl:with-param>
				<xsl:with-param name="currentSortField"><xsl:value-of select="../../LIST/@ORDER-BY"/></xsl:with-param>
				<xsl:with-param name="currentSortType"><xsl:value-of select="../../LIST/@ORDER-TYPE"/></xsl:with-param>
				<xsl:with-param name="tab">users</xsl:with-param>
			</xsl:call-template>

			<th>
				<div><xsl:value-of select="FULL-NAME"/></div>
			</th>
		
			<xsl:call-template name="LIST-HEADER-ITEM">
				<xsl:with-param name="field">creation_date</xsl:with-param>
				<xsl:with-param name="title"><xsl:value-of select="CREATION-DATE"/></xsl:with-param>
				<xsl:with-param name="currentSortField"><xsl:value-of select="../../LIST/@ORDER-BY"/></xsl:with-param>
				<xsl:with-param name="currentSortType"><xsl:value-of select="../../LIST/@ORDER-TYPE"/></xsl:with-param>
				<xsl:with-param name="align">right</xsl:with-param>
				<xsl:with-param name="tab">users</xsl:with-param>
			</xsl:call-template>			
		</tr> 
	</xsl:template>
	
	<xsl:template match="USERS/PAGED-LIST/LIST/ITEM">
		<xsl:variable name="class">
			<xsl:call-template name="LIST-ROW-CLASS">
				<xsl:with-param name="position"><xsl:value-of select="position()"/></xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		
		<tr class="{$class}">
			<td style="width:1%;">
				<input type="checkbox" name="objectIds[]" class="check">
					<xsl:attribute name="value"><xsl:value-of select="ID"/></xsl:attribute>
				</input>
			</td>
			
			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="icon">
					<xsl:choose>
						<xsl:when test="STATUS = '1'">run.png</xsl:when>
						<xsl:otherwise>shutdown.png</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
			</xsl:call-template>
		
			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="title"><xsl:value-of select="NAME"/></xsl:with-param>
				<xsl:with-param name="action"><xsl:value-of select="$baseUrl"/>/Wizard/Edit/Modules/Login/Edit?userId=<xsl:value-of select="ID"/></xsl:with-param>
			</xsl:call-template>
		
			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="title"><xsl:value-of select="EMAIL"/></xsl:with-param>
			</xsl:call-template>
		
			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="title"><xsl:value-of select="FIRST-NAME"/>&#160;<xsl:value-of select="LAST-NAME"/></xsl:with-param>
			</xsl:call-template>
		
			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="title"><xsl:value-of select="CREATION-DATE"/></xsl:with-param>
				<xsl:with-param name="align">right</xsl:with-param>
			</xsl:call-template>
		</tr>
	</xsl:template>

</xsl:stylesheet>